<?php
/*
Plugin Name: DirectPay Payment Gateway-V3
Description: DirectPay Payment Gateway allows you to accept payment on your Woocommerce store via Visa, MasterCard, AMEX, Frimi, Ipay & LankaQR services.
Version: 3.0.7
Author: DirectPay (Private) Limited
Author URI: https://www.directpay.lk
WC requires at least: 3.2.0
WC tested up to: 5.3
*/

/**
 * Check if WooCommerce is active and at the required minimum version.
 *
 * @since 1.0
 */
if (!in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    add_action('admin_notices', function () {
        $class = 'notice notice-error is-dismissible';
        $message = __('Woocommerce DirectPay Payment Gateway is enabled but not effective. It requires WooCommerce in order to work.', 'woo_directPayV3');
        printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), esc_html($message));
    });
    return;
}


add_action('plugins_loaded', 'directPayV3_init_gateway_class');
function directPayV3_init_gateway_class()
{
    include 'classes/WC_Gateway_DirectPay.php';
    add_filter('woocommerce_payment_gateways', 'directPayV3_add_gateway_class');
}

/*
 * This action hook registers our PHP class as a WooCommerce payment gateway
 */
function directPayV3_add_gateway_class($gateways)
{
    $gateways[] = 'WC_DirectPayV3_Gateway';
    return $gateways;
}


/**
 * 'Settings' link on plugin page
 **/
add_filter('plugin_action_links', 'directPayV3_add_action_plugin', 10, 5);
function directPayV3_add_action_plugin($actions, $plugin_file)
{
    static $plugin;
    if (!isset($plugin))
        $plugin = plugin_basename(__FILE__);
    if ($plugin == $plugin_file) {
        $settings = array('settings' => '<a href="admin.php?page=wc-settings&tab=checkout&section=WC_DirectPayV3_Gateway">' . __('Settings') . '</a>');
        $actions = array_merge($settings, $actions);
    }
    return $actions;
}


add_action('wp_ajax_directPayV3_client_note', 'directPayV3_ajax_client_note');
add_action('wp_ajax_nopriv_directPayV3_client_note', 'directPayV3_ajax_client_note');
function directPayV3_ajax_client_note()
{
    $_wc_gtway = new WC_DirectPayV3_Gateway();
    echo json_encode(array('data' => $_wc_gtway->createClientNote()));
    exit();
}

add_action( 'wp_footer', 'directPayV3_send_thankyou_ajax' );
function directPayV3_send_thankyou_ajax(){

    if( !is_wc_endpoint_url( 'order-received' ) ) return;
    echo '
        <script>
            jQuery( function( $ ) {
                $(".woocommerce-order-overview").append("<li>Payment status:<strong>"+sessionStorage.getItem("dp_msg")+"</strong></li>")
            });
        </script>
    ';

}

// Custom Order Statuses

// Register Pending Slip Status
function directPayV3_register_pending_order_status() {
    $label = "Pending Directpay Payment";
    register_post_status( 'wc-pending-dp', array(
        'label'                     => $label,
        'public'                    => true,
        'exclude_from_search'       => false,
        'show_in_admin_all_list'    => true,
        'show_in_admin_status_list' => true,
        'label_count'               => _n_noop( $label.' (%s)', $label.' (%s)' )
    ) );
}

// Register Pending Approval Status
function directPayV3_register_pending_approval_order_status() {
    $label = "Pending Directpay Payment Approval";
    register_post_status( 'wc-pending-approval', array(
        'label'                     => $label,
        'public'                    => true,
        'exclude_from_search'       => false,
        'show_in_admin_all_list'    => true,
        'show_in_admin_status_list' => true,
        'label_count'               => _n_noop( $label.' (%s)', $label.' (%s)' )
    ) );
}
// END - Custom Order Statuses

// Add Pending Approval Status to list of WC Order statuses
function directPayV3_add_custom_order_statuses( $order_statuses ) {
    $new_order_statuses = array();

    foreach ( $order_statuses as $key => $status ) {

        $new_order_statuses[ $key ] = $status;

        if ( 'wc-pending' === $key ) {
            $new_order_statuses['wc-pending-dp'] = "Pending Directpay Payment";
            $new_order_statuses['wc-pending-approval'] = "Directpay Payment Approval";
        }
    }

    return $new_order_statuses;
}

function directPayV3_add_admin_additional_scripts(){
    wp_enqueue_style('directPayV3-admin-styles', plugin_dir_url(__FILE__). 'assets/css/admin-style.css');
}

add_action( 'init', 'directPayV3_register_pending_order_status');
add_action( 'init', 'directPayV3_register_pending_approval_order_status');
add_filter( 'wc_order_statuses', 'directPayV3_add_custom_order_statuses' );
add_action('admin_enqueue_scripts', 'directPayV3_add_admin_additional_scripts');